@@ -117,17 +117,12 @@ module GObject
     end
 
     def property_param_spec(property_name)
-      object_class.find_property property_name or
+      class_struct.find_property property_name or
         raise GirFFI::PropertyNotFoundError.new(property_name, self.class)
     end
 
     # Overrides for GObject, GObject's generic base class.
     module Overrides
-      # @deprecated
-      def get_property_extended(property_name)
-        get_property(property_name)
-      end
-
       def get_property(property_name)
         gvalue = gvalue_for_property property_name
         super property_name, gvalue
@@ -139,11 +134,6 @@ module GObject
         value
       end
 
-      # @deprecated
-      def set_property_extended(property_name, value)
-        set_property property_name, value
-      end
-
       def set_property(property_name, value)
         type_info = get_property_type property_name
         value = property_value_pre_conversion(value, type_info) if type_info
