@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'ffi'
+require "ffi"
 
 module GObjectIntrospection
   # Provides access to the g_type_init function.
@@ -12,7 +12,7 @@ module GObjectIntrospection
     # Module for attaching g_type_init from the gobject library.
     module Lib
       extend FFI::Library
-      ffi_lib 'gobject-2.0'
+      ffi_lib "gobject-2.0"
       attach_function :g_type_init, [], :void
     end
   end
