@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/enum_builder'
-require 'gir_ffi/flags_base'
+require "gir_ffi/builders/enum_builder"
+require "gir_ffi/flags_base"
 
 module GirFFI
   module Builders
