@@ -89,7 +89,7 @@ module GirFFI
         lib.extend FFI::BitMasks
         lib.ffi_lib_flags :global, :lazy
         if shared_library_specification
-          lib.ffi_lib(*shared_library_specification.split(/,/))
+          lib.ffi_lib(*shared_library_specification.split(","))
         end
       end
 
