@@ -7,8 +7,8 @@ module GirFFI
   class ObjectBase < ClassBase
     extend FFI::DataConverter
 
-    def object_class
-      self.class.object_class
+    def class_struct
+      self.class.class_struct
     end
 
     def self.native_type
@@ -64,11 +64,11 @@ module GirFFI
         raise GirFFI::SignalNotFoundError.new(name, self)
     end
 
-    def self.object_class
-      @object_class ||=
+    def self.class_struct
+      @class_struct ||=
         begin
           ptr = GObject::Lib.g_type_class_ref(gtype)
-          gir_ffi_builder.object_class_struct.wrap ptr
+          gir_ffi_builder.class_struct_class.wrap ptr
         end
     end
 
